JAXScape provides connectivity and sensitivity analysis utilities, based on the opiniated definition of ecological connectivity as the sum of ecological proximity, which can process large rasters efficiently using windowed operations. Users who want to obtain a finer control over the definition of ecological connectivity can use the lower-level window operations directly (see [Window operations](window_operations.md)).

::: jaxscape.connectivity_analysis.ConnectivityAnalysis
    options:
      members:
        - run
      show_bases: false

::: jaxscape.connectivity_analysis.SensitivityAnalysis
    options:
      members:
        - run
      show_bases: false